<?php

    class GetEmails
    {

        private $apiUrl = 'https://alfamiller.com/api/v1/index.php?job=get.emails.sent';
        private $apiKey;

        public function __construct($apiKey, $apiUrl = null)
        {
            $this->apiKey = trim($apiKey);

            if ($apiUrl !== null) {
                $this->apiUrl = trim($apiUrl);
            }
        }


        public function getEmails()
        {
            $resultObj = new stdClass();

            try {
                $debugData = [];

                if (!$this->apiUrl) {
                    throw new Exception('API URL is not set.', 200);
                }

                if (!$this->apiKey) {
                    throw new Exception('API key is not set.', 200);
                }


                $headers = [
                    'Authorization: Bearer ' . $this->apiKey,
                    'Content-Type: application/json',
                ];

                $curlObj = curl_init($this->apiUrl);

                curl_setopt($curlObj, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($curlObj, CURLOPT_POST, true);
                curl_setopt($curlObj, CURLOPT_HTTPHEADER, $headers);

                $curlRequestResponse = curl_exec($curlObj);

                $curlRequestHttpCode = curl_getinfo($curlObj, CURLINFO_HTTP_CODE);

                if (curl_errno($curlObj)) {
                    $curlErrorMsg = curl_error($curlObj);
                    curl_close($curlObj);

                    throw new Exception($curlErrorMsg, 200);
                }

                curl_close($curlObj);

                $debugData['apiUrl']             = $this->apiUrl;
                $debugData['apiRequestHttpCode'] = $curlRequestHttpCode;
                $debugData['apiResponse']        = $curlRequestResponse;
                $debugData['headersSent']        = $headers;

                if ($curlRequestHttpCode >= 400) {
                    throw new Exception('API request failed. Non-200 header code received from API.', 200);
                }

                //dd($curlRequestResponse);
                $curlRequestResponse = json_decode($curlRequestResponse);

                $resultObj->response       = $curlRequestResponse;
                $resultObj->localDebugData = $debugData;

            } catch (Exception $e) {
                $resultObj->res            = 0;
                $resultObj->errorMsg       = $e->getCode() == 200 ? $e->getMessage() : 'Error occurred. Contact system administrators.';
                $resultObj->localDebugData = $debugData;
            }

            return $resultObj;
        }
    }