<?php

    class SendEmail
    {

        private $apiUrl = 'https://alfamiller.com/api/v1/index.php?job=send.email';
        private $apiKey;
        private $toEmail;
        private $fromEmail;
        private $fromName;
        private $subject;
        private $htmlBody;
        private $textBody;
        private $ccEmail;
        private $bccEmail;
        private $attachments;

        public function __construct($apiKey, $apiUrl = null)
        {
            $this->apiKey = trim($apiKey);

            if ($apiUrl !== null) {
                $this->apiUrl = trim($apiUrl);
            }
        }

        public function setToEmail($toEmail)
        {
            $this->toEmail = $toEmail;

            return $this;
        }

        public function getToEmail()
        {
            return $this->toEmail;
        }

        public function setFromEmail($fromEmail)
        {
            $this->fromEmail = $fromEmail;

            return $this;
        }

        public function getFromEmail()
        {
            return $this->fromEmail;
        }

        public function setSubject($subject)
        {
            $this->subject = $subject;

            return $this;
        }

        public function getSubject()
        {
            return $this->subject;
        }

        public function setHtmlBody($htmlBody)
        {
            $this->htmlBody = $htmlBody;

            return $this;
        }

        public function getHtmlBody()
        {
            return $this->htmlBody;
        }

        public function setTextBody($textBody)
        {
            $this->textBody = $textBody;

            return $this;
        }

        public function getTextBody()
        {
            return $this->textBody;
        }

        public function setFromName($fromName)
        {
            $this->fromName = $fromName;

            return $this;
        }

        public function getFromName()
        {
            return $this->fromName;
        }

        public function setCcEmail($ccEmail)
        {
            $this->ccEmail = $ccEmail;

            return $this;
        }

        public function getCcEmail()
        {
            return $this->ccEmail;
        }

        public function setBccEmail($bccEmail)
        {
            $this->bccEmail = $bccEmail;

            return $this;
        }

        public function getBccEmail()
        {
            return $this->bccEmail;
        }

        public function setAttachments($attachments)
        {
            $this->attachments = $attachments;

            return $this;
        }

        public function getAttachments()
        {
            return $this->attachments;
        }

        public function sendEmail()
        {
            $resultObj = new stdClass();

            try {
                $maildata  = [];
                $debugData = [];

                if (!$this->apiUrl) {
                    throw new Exception('API URL is not set.', 200);
                }

                if (!$this->apiKey) {
                    throw new Exception('API key is not set.', 200);
                }


                if (!$this->textBody && !$this->htmlBody) {
                    throw new Exception('Text body or HTML body is not set.', 200);
                }

                $maildata['toEmail']   = $this->toEmail;
                $maildata['fromEmail'] = $this->fromEmail;
                $maildata['subject']   = $this->subject;

                if ($this->textBody) {
                    $maildata['textBody'] = $this->textBody;
                }

                if ($this->htmlBody) {
                    $maildata['htmlBody'] = $this->htmlBody;
                }

                if (!$maildata['toEmail']) {
                    throw new Exception('To email is not set.', 200);
                }

                if (!$maildata['fromEmail']) {
                    throw new Exception('From email is not set.', 200);
                }

                if ($this->fromName) {
                    $maildata['fromName'] = $this->fromName;
                }

                if (!$maildata['subject']) {
                    throw new Exception('Subject is not set.', 200);
                }


                if ($this->ccEmail) {
                    $maildata['cc'] = $this->ccEmail;
                }

                if ($this->bccEmail) {
                    $maildata['bcc'] = $this->bccEmail;
                }

                if ($this->attachments) {
                    $encodedAttachments = [];
                    foreach ($this->attachments as $attachment) {
                        if (!$attachment['filename'] || !$attachment['content'] || !$attachment['contentType']) {
                            throw new Exception('Invalid attachment data. Missing filename, content, or contentType.', 200);
                        }

                        $encodedAttachments[] = [
                            'filename'    => $attachment['filename'],
                            'content'     => base64_encode($attachment['content']),
                            'contentType' => $attachment['contentType'],
                        ];
                    }

                    $maildata['attachments'] = $encodedAttachments;
                }

                $headers = [
                    'Authorization: Bearer ' . $this->apiKey,
                    'Content-Type: application/json',
                ];

                $curlObj = curl_init($this->apiUrl);

                curl_setopt($curlObj, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($curlObj, CURLOPT_POST, true);
                curl_setopt($curlObj, CURLOPT_POSTFIELDS, json_encode($maildata));
                curl_setopt($curlObj, CURLOPT_HTTPHEADER, $headers);

                $curlRequestResponse = curl_exec($curlObj);

                $curlRequestHttpCode = curl_getinfo($curlObj, CURLINFO_HTTP_CODE);

                if (curl_errno($curlObj)) {
                    $curlErrorMsg = curl_error($curlObj);
                    curl_close($curlObj);

                    throw new Exception($curlErrorMsg, 200);
                }

                curl_close($curlObj);

                $debugData['apiUrl']             = $this->apiUrl;
                $debugData['apiRequestHttpCode'] = $curlRequestHttpCode;
                $debugData['apiResponse']        = $curlRequestResponse;
                $debugData['maildataSent']       = $maildata;

                if ($curlRequestHttpCode >= 400) {
                    throw new Exception('Email sending failed. Non-200 header code received from API.', 200);
                }

                $curlRequestResponse = json_decode($curlRequestResponse);

                $resultObj->res            = $curlRequestResponse->res;
                $resultObj->response       = $curlRequestResponse;
                $resultObj->localDebugData = $debugData;

            } catch (Exception $e) {
                $resultObj->res            = 0;
                $resultObj->errorMsg       = $e->getCode() == 200 ? $e->getMessage() : 'Error occurred. Contact system administrators.';
                $resultObj->localDebugData = $debugData;
            }

            return $resultObj;
        }
    }