# AlfaMiller API Documentation
## GetEmails Class API Documentation
A PHP class for retrieving sent emails through the alfamiller.com API.
## Installation
This class requires PHP with cURL support.
## Basic Usage
``` php
// Initialize with API key
$emailClient = new GetEmails('your-api-key');

// Retrieve sent emails
$result = $emailClient->getEmails();

// Access the response data
if (isset($result->response)) {
    $emails = $result->response;
    // Process emails
}
```
## Constructor
``` php
public function __construct($apiKey, $apiUrl = null)
```
| Parameter | Type | Description |
| --- | --- | --- |
| `$apiKey` | string | Required. Your API key for alfamiller.com |
| `$apiUrl` | string | Optional. Custom API endpoint URL |
## Methods
### getEmails
``` php
public function getEmails()
```
Retrieves the list of sent emails from the API.
#### Return Value
Returns a `stdClass` object with the following properties:

| Property | Type | Description |
| --- | --- | --- |
| `response` | object | The API response containing the emails data (when successful) |
| `localDebugData` | array | Debug information including API URL, response codes, headers, etc. |
| `res` | int | Set to 0 when an error occurs |
| `errorMsg` | string | Error message when an exception is caught |
#### Exceptions
The method handles exceptions internally and includes error information in the returned object. Common error cases include:
- API URL not set (code 200)
- API key not set (code 200)
- cURL errors (code 200)
- Non-200 HTTP response codes (code 200)

## Authentication
The class uses Bearer token authentication with the provided API key:
``` 
Authorization: Bearer your-api-key
```
## Notes
- The default API URL is '[https://alfamiller.com/api/v1/index.php?job=get.emails.sent](https://alfamiller.com/api/v1/index.php?job=get.emails.sent)'
- All API communication uses POST requests
- The API response is parsed from JSON to PHP objects automatically
- Debug information is included in the result object for troubleshooting

This class complements the `SendEmail` class for a complete email management solution.
