# AlfaMiller API Documentation
## SendEmail Class API Documentation
A PHP class for sending emails through the alfamiller.com API.
## Installation
This class requires PHP with cURL support.
## Basic Usage
``` php
// Initialize with API key
$emailer = new SendEmail('your-api-key');

// Configure email parameters using fluent interface
$emailer->setToEmail('recipient@example.com')
       ->setFromEmail('sender@example.com')
       ->setFromName('Sender Name')
       ->setSubject('Email Subject')
       ->setHtmlBody('<p>Email content in HTML</p>')
       ->setTextBody('Plain text email content')
       ->sendEmail();
```
## Constructor
``` php
public function __construct($apiKey, $apiUrl = null)
```
| Parameter | Type | Description |
| --- | --- | --- |
| `$apiKey` | string | Required. Your API key for alfamiller.com |
| `$apiUrl` | string | Optional. Custom API endpoint URL |
## Methods
### Configuration Methods
All setter methods return the instance for method chaining.

| Method | Description |
| --- | --- |
| `setToEmail($toEmail)` | Sets recipient email address |
| `setFromEmail($fromEmail)` | Sets sender email address |
| `setFromName($fromName)` | Sets sender name |
| `setSubject($subject)` | Sets email subject |
| `setHtmlBody($htmlBody)` | Sets HTML version of email content |
| `setTextBody($textBody)` | Sets plain text version of email content |
| `setCcEmail($ccEmail)` | Sets CC recipient(s) |
| `setBccEmail($bccEmail)` | Sets BCC recipient(s) |
| `setAttachments($attachments)` | Sets email attachments |
### Getter Methods

| Method | Returns |
| --- | --- |
| `getToEmail()` | Recipient email address |
| `getFromEmail()` | Sender email address |
| `getFromName()` | Sender name |
| `getSubject()` | Email subject |
| `getHtmlBody()` | HTML version of email content |
| `getTextBody()` | Plain text version of email content |
| `getCcEmail()` | CC recipient(s) |
| `getBccEmail()` | BCC recipient(s) |
| `getAttachments()` | Email attachments |
### Send Method
``` php
public function sendEmail()
```
Sends the email with the configured parameters.
#### Requirements
- API key must be set
- Recipient email (`toEmail`) must be set
- Sender email (`fromEmail`) must be set
- At least one of HTML body or text body must be set

#### Exceptions
Throws exceptions with code 200 when required fields are missing.
## Notes
- The default API URL is '[https://alfamiller.com/api/v1/index.php?job=send.email](https://alfamiller.com/api/v1/index.php?job=send.email)'
- Both HTML and plain text versions of the email can be provided
- At least one body format (HTML or plain text) is required
